@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="1.0.16"
+UPGRADE_VER="1.0.18"
 TARGET_PREFIX=sp80_upgrade_
 BIN_PATH=/home/root
 CARD_PATH=${MOUNTR}
@@ -39,6 +39,7 @@ NAND_WR=${RAM_PATH}/${NWRITE_NAME}
 # NAND STORAGE
 OUT_DD_DEV=/dev/mtdblock5
 OUT_CHAR_DEV=/dev/mtd5
+PVT_CHAR_DEV=/dev/mtd9
 BOOT_DD_DEV=/dev/mtdblock0
 BOOT_CHAR_DEV=/dev/mtd0
 
@@ -63,6 +64,12 @@ do_reboot() {
     rm -rf ${CARD_PATH}/${RFS_NAME}* ${CARD_PATH}/${KERN_NAME}* ${CARD_PATH}/${BOOT_NAME}* ${CARD_PATH}/upl_start.log
     rm -rf ${CARD_PATH}/${XLDR_NAME}*
   fi
+  if [ $(grep -c "UERR 1" /proc/sp4) -eq 1 ]; then
+    if [ -f /mnt/card/*.tar ]; then
+      echo "Removing tar from /mnt/card"  | tee -a ${LOG}
+      rm -f /mnt/card/*.tar
+    fi
+  fi
   displ ${2}
   echo "Rebooting" | tee -a ${LOG}
   reboot
@@ -200,7 +207,6 @@ if [ "$fl_continue" -eq "0" ]; then
 	 if [ $? -eq 0 ]; then
    echo "Error to upgrade. Warranty period exceeds !!!" | tee -a ${LOG}
    echo "Ending upgrade script at " $(date) | tee -a ${LOG}
-   umount ${DEVICE}
    echo "UERR 1" > /proc/sp4
    do_reboot 1 "Not Allowed"
 	 fi
@@ -372,6 +378,12 @@ if [ "$fl_continue" -eq "0" ]; then
 
       echo "$XLDR_NAME copy reset at ${OUT_CHAR_DEV}" | tee -a ${LOG}
       flash_erase ${OUT_CHAR_DEV} 0x0 | tee -a ${LOG}
+      fs_flush
+
+      # echo "Erase PVT partition ${PVT_CHAR_DEV}" | tee -a ${LOG}
+      # flash_erase ${PVT_CHAR_DEV} 0x0 | tee -a ${LOG}
+      # fs_flush
+   
       fl_kupl=1
  fi
 
@@ -721,9 +733,8 @@ cd ${BIN_PATH}
 tar -x${TAR_OPT} ${TAR_FILE} productVersion.txt
 new_ver=$(cat productVersion.txt)
 
-echo "Removing prev.data" | tee -a ${LOG}
+echo "Sync" | tee -a ${LOG}
 fs_flush
-rm -rf /mnt/pvt/antenna
 sync
 
 cd ${RAM_PATH}
